@@ -3,10 +3,11 @@
 
 """Defines the Model Analysis Dashboard class."""
 
+import warnings
+
 from responsibleai import RAIInsights
 
 from .responsibleai_dashboard import ResponsibleAIDashboard
-import warnings
 
 
 class ModelAnalysisDashboard(object):
@@ -22,13 +23,16 @@ class ModelAnalysisDashboard(object):
     :type public_ip: str
     :param port: The port to use on locally hosted service.
     :type port: int
-
+    :param locale: The language in which user wants to load and access the
+        ModelAnalysis Dashboard. The default language is english ("en").
+    :type locale: str
     """
-
     def __init__(self, analysis: RAIInsights,
                  public_ip=None, port=None, locale=None):
-        warnings.warn("ModelAnalysisDashboard in raiwidgets package is "
+        warnings.warn("MODULE-DEPRECATION-WARNING: "
+                      "ModelAnalysisDashboard in raiwidgets package is "
                       "deprecated."
-                      "Please use ResponsibleAIDashboard instead.")
+                      "Please use ResponsibleAIDashboard instead.",
+                      DeprecationWarning)
         rai = ResponsibleAIDashboard(analysis, public_ip, port, locale)
         self.input = rai.input
