@@ -5,11 +5,11 @@
 
 from flask import jsonify, request
 
+from raiwidgets.dashboard import Dashboard
+from raiwidgets.responsibleai_dashboard_input import \
+    ResponsibleAIDashboardInput
 from responsibleai import RAIInsights
 
-from .dashboard import Dashboard
-from .responsibleai_dashboard_input import ResponsibleAIDashboardInput
-
 
 class ResponsibleAIDashboard(Dashboard):
     """The dashboard class, wraps the dashboard component.
@@ -24,10 +24,15 @@ class ResponsibleAIDashboard(Dashboard):
     :param locale: The language in which user wants to load and access the
         ResponsibleAI Dashboard. The default language is english ("en").
     :type locale: str
+    :param cohort_list:
+        List of cohorts defined by the user for the dashboard.
+    :type cohort_list: List[Cohort]
     """
     def __init__(self, analysis: RAIInsights,
-                 public_ip=None, port=None, locale=None):
-        self.input = ResponsibleAIDashboardInput(analysis)
+                 public_ip=None, port=None, locale=None,
+                 cohort_list=None, **kwargs):
+        self.input = ResponsibleAIDashboardInput(
+            analysis, cohort_list=cohort_list)
 
         super(ResponsibleAIDashboard, self).__init__(
             dashboard_type="ResponsibleAI",
@@ -35,7 +40,8 @@ class ResponsibleAIDashboard(Dashboard):
             public_ip=public_ip,
             port=port,
             locale=locale,
-            no_inline_dashboard=True)
+            no_inline_dashboard=True,
+            **kwargs)
 
         def predict():
             data = request.get_json(force=True)
@@ -45,22 +51,35 @@ class ResponsibleAIDashboard(Dashboard):
         def tree():
             data = request.get_json(force=True)
             return jsonify(self.input.debug_ml(data))
-
         self.add_url_rule(tree, '/tree', methods=["POST"])
 
         def matrix():
             data = request.get_json(force=True)
             return jsonify(self.input.matrix(data))
-
         self.add_url_rule(matrix, '/matrix', methods=["POST"])
 
         def causal_whatif():
             data = request.get_json(force=True)
             return jsonify(self.input.causal_whatif(data))
-
         self.add_url_rule(causal_whatif, '/causal_whatif', methods=["POST"])
 
+        def global_causal_effects():
+            data = request.get_json(force=True)
+            return jsonify(self.input.get_global_causal_effects(data))
+        self.add_url_rule(global_causal_effects, '/global_causal_effects',
+                          methods=["POST"])
+
+        def global_causal_policy():
+            data = request.get_json(force=True)
+            return jsonify(self.input.get_global_causal_policy(data))
+        self.add_url_rule(global_causal_policy, '/global_causal_policy',
+                          methods=["POST"])
+
         def importances():
             return jsonify(self.input.importances())
-
         self.add_url_rule(importances, '/importances', methods=["POST"])
+
+        def get_exp():
+            data = request.get_json(force=True)
+            return jsonify(self.input.get_exp(data))
+        self.add_url_rule(get_exp, '/get_exp', methods=["POST"])
